@@ -1,12 +1,13 @@
+import itertools
 import logging
 from collections import defaultdict
 from dataclasses import dataclass
 from typing import List, Dict, Type, Union, Optional
-from async_tools import AsyncOnStart
+from async_tools.async_initable import AsyncInitable
 from dict_caster.extras import to_list
 
 from .elements.aggregation_function import AggregationFunction
-from .elements.filter_by import Filter
+from .elements.filter_by import Filter, Condition
 from .elements.order import Order
 from .elements.column import Column
 from .exceptions import WrongArgumentsException
@@ -18,16 +19,17 @@ from .clickhouse_connector import ClickHouseConnector
 logger = logging.getLogger(__file__)
 
 
-class ClickHouseInterface(AsyncOnStart):
+class ClickHouseInterface(AsyncInitable):
     @dataclass
     class Context:
         clickhouse_connector: ClickHouseConnector
 
     def __init__(self, context: Context):
+        AsyncInitable.__init__(self)
         self.context = context
         self._name_to_entity: Dict[str, Type[Table]] = {}
 
-    async def _on_start(self) -> None:
+    async def async_init(self) -> None:
         for table in self._name_to_entity.values():
             await self.context.clickhouse_connector.create_table(table)
 
@@ -63,10 +65,16 @@ class ClickHouseInterface(AsyncOnStart):
         group_by: List[Column] = entity.groups_from_str(group_by)
         output_format: OutputFormat = entity.output_format_from_str(output_format)
         aggregation_functions: List[AggregationFunction] = entity.aggregation_functions_from_str(aggregation_functions)
+        selectables = list(itertools.chain.from_iterable((columns or [], aggregation_functions or [])))
 
+        condition = Condition()
+        for filter_ in filter_by:
+            condition.add_and(filter_)
+        for search in search_by:
+            condition.add_or(search)
         result = await self.context.clickhouse_connector.select(
-            entity, columns=columns, filter_by=filter_by, search_by=search_by, order_by=order_by, group_by=group_by,
-            offset=offset, limit=limit, output_format=output_format, aggregation_functions=aggregation_functions)
+            entity, selectables=selectables, condition=condition, order_by=order_by, group_by=group_by,
+            offset=offset, limit=limit, output_format=output_format)
         return result
 
     async def count(self,
